FFmpeg
Loading...
Searching...
No Matches
transpose.c
Go to the documentation of this file.
1// Generated from libavfilter/opencl/transpose.cl
3"/*\n"
4" * This file is part of FFmpeg.\n"
5" *\n"
6" * FFmpeg is free software; you can redistribute it and/or\n"
7" * modify it under the terms of the GNU Lesser General Public\n"
8" * License as published by the Free Software Foundation; either\n"
9" * version 2.1 of the License, or (at your option) any later version.\n"
10" *\n"
11" * FFmpeg is distributed in the hope that it will be useful,\n"
12" * but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
13" * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU\n"
14" * Lesser General Public License for more details.\n"
15" *\n"
16" * You should have received a copy of the GNU Lesser General Public\n"
17" * License along with FFmpeg; if not, write to the Free Software\n"
18" * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA\n"
19" */\n"
20"kernel void transpose(__write_only image2d_t dst,\n"
21" __read_only image2d_t src,\n"
22" int dir) {\n"
23" const sampler_t sampler = (CLK_NORMALIZED_COORDS_FALSE |\n"
24" CLK_ADDRESS_CLAMP_TO_EDGE |\n"
25" CLK_FILTER_NEAREST);\n"
26"\n"
27" int2 size = get_image_dim(dst);\n"
28" int x = get_global_id(0);\n"
29" int y = get_global_id(1);\n"
30"\n"
31" int xin = (dir & 2) ? (size.y - 1 - y) : y;\n"
32" int yin = (dir & 1) ? (size.x - 1 - x) : x;\n"
33" float4 data = read_imagef(src, sampler, (int2)(xin, yin));\n"
34"\n"
35" if (x < size.x && y < size.y)\n"
36" write_imagef(dst, (int2)(x, y), data);\n"
37"}\n"
38;
const char * ff_source_transpose_cl
Definition transpose.c:2